"use strict";

/**
 * Object 对象扩展
 */
/**
 * 获取对象数据类型
 *
 * @param obj 对象变量
 * @return 对象数据类型
 */
import _typeof from "@babel/runtime/helpers/esm/typeof";
Object.type = function (obj) {
  return _typeof(obj);
};
/**
 * 获取对象数据类型
 *
 * @param obj 对象变量
 * @return 对象数据类型
 */
Object.rawType = function (obj) {
  return Object.prototype.toString.call(obj).slice(8, -1);
};
/**
 * 判断对象是否为 object 类型
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isObject = function (obj) {
  return obj !== null && _typeof(obj) === "object";
};
/**
 * 判断对象是否为 object 类型
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isPlainObject = function (obj) {
  return Object.prototype.toString.call(obj) === "[object Object]";
};
/**
 * 判断对象是否为 Map 类型
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isMap = function (obj) {
  return Object.prototype.toString.call(obj) === "[object Map]";
};
/**
 * 判断对象是否为 Set 类型
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isSet = function (obj) {
  return Object.prototype.toString.call(obj) === "[object Set]";
};
/**
 * 判断对象是否为函数
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isFunction = function (obj) {
  return Object.type(obj) === "function";
};
/**
 * 判断对象是否为 Symbol
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isSymbol = function (obj) {
  if (_typeof(obj) === "symbol") {
    return true;
  }
  try {
    var _toString = Symbol.prototype.toString;
    if (_typeof(obj.valueOf()) !== "symbol") {
      return false;
    }
    return /^Symbol\(.*\)$/.test(_toString.call(obj));
  } catch (e) {
    return false;
  }
};
/**
 * 判断对象是否为 Promise
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isPromise = function (obj) {
  return Object.isUndefinedOrNull(obj) === false && Object.isFunction(obj.then) === true && Object.isFunction(obj["catch"]) === true;
};
/**
 * 判断对象是否为原始类型
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isPrimitive = function (obj) {
  return Object.isBoolean(obj) === true || Object.isString(obj) === true || Object.isNumber(obj) === true;
};
/**
 * 判断对象是否为数组
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isArray = function (obj) {
  return Array.isArray(obj) === true;
};
/**
 * 判断对象是否为字符串对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isString = function (obj) {
  return Object.type(obj) === "string";
};
/**
 * 判断对象是否为数字对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isNumber = function (obj) {
  return Object.type(obj) === "number";
};
/**
 * 判断对象是否为布尔对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isBoolean = function (obj) {
  return Object.type(obj) === "boolean";
};
/**
 * 判断对象是否为正则对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isRegExp = function (obj) {
  return Object.rawType(obj) === 'RegExp';
};
/**
 * 判断对象是否为文件对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isFile = function (obj) {
  return obj instanceof File;
};
/**
 * 判断对象是否为 windows 对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isWindow = function (obj) {
  return Object.isUndefinedOrNull(obj) && obj == obj.window;
};
/**
 * 判断对象是否为 Element
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isElement = function (obj) {
  if (Object.isUndefinedOrNull(obj)) {
    return false;
  }
  return !!(obj.nodeType == 1);
};
/**
 * 判断对象是否为事件对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isEvent = function (obj) {
  return obj instanceof Event;
};
/**
 * 判断对象是否为 null 对象
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isNull = function (obj) {
  return obj === null;
};
/**
 * 判断对象是否为未定义
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isUndefined = function (obj) {
  return obj === undefined;
};
/**
 * 判断对象是否为未定义或 null
 *
 * @param obj 任意对象
 * @return boolean
 */
Object.isUndefinedOrNull = function (obj) {
  return Object.isUndefined(obj) === true || Object.isNull(obj) === true;
};
/**
 * 判断两个对象是否相等
 *
 * @param obj1 一个对象
 * @param obj2 用于和 obj1 比较的对象
 * @return 当两个对象相等时，返回 true；否则，返回 false
 */
Object.equals = function (obj1, obj2) {
  if (obj1 === obj2) {
    return true;
  } else if (!(obj1 instanceof Object) || !(obj2 instanceof Object)) {
    return false;
  } else if (obj1.constructor !== obj2.constructor) {
    return false;
  } else if (Object.isArray(obj1) && Object.isArray(obj2) && obj1.length === obj2.length) {
    for (var i = 0; i < obj1.length; i++) {
      if (Object.equals(obj1[i], obj2[i]) === false) {
        return false;
      }
    }
  } else if (Object.isObject(obj1) && Object.isObject(obj2) && Object.keys(obj1).length === Object.keys(obj2).length) {
    for (var key in obj1) {
      if (obj1.hasOwnProperty.call(key)) {
        if (Object.equals(obj1[key], obj2[key]) === false) {
          return false;
        }
      }
    }
  } else {
    return false;
  }
  return true;
};
/**
 * 克隆对象
 *
 * @param obj 任意对象
 * @return 新对象实例
 */
Object.clone = function (obj) {
  if (Object.isString(obj)) {
    return String(obj);
  } else if (Object.isArray(obj)) {
    return Array.prototype.slice.apply(obj);
  } else if (Object.isPlainObject(obj)) {
    var result = Object.create(null);
    Object.keys(obj).forEach(function (key) {
      result[key] = Object.clone(obj[key]);
    });
    return result;
  }
  return obj;
};
/**
 * 克隆对象，但需要删除指定属性
 *
 * @param obj 任意对象
 * @param fields 需要删除的属性
 * @return 新对象实例
 */
Object.omit = function (obj) {
  var result = Object.clone(obj);
  for (var i = 0; i < (arguments.length <= 1 ? 0 : arguments.length - 1); i++) {
    var key = i + 1 < 1 || arguments.length <= i + 1 ? undefined : arguments[i + 1];
    delete result[key];
  }
  return result;
};
/**
 * 返回对象指定属性，生成新对象
 *
 * @param obj 任意对象
 * @param fields 需要返回的属性
 * @return 新对象实例
 * @since 4.1.0
 */
Object.pick = function (obj) {
  var result = {};
  for (var _len = arguments.length, fields = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    fields[_key - 1] = arguments[_key];
  }
  fields.forEach(function (key) {
    result[key] = obj[key];
  });
  return result;
};