"use strict";

/**
 * Optional 对象
 */
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));
var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));
var Optional = /*#__PURE__*/function () {
  /**
   * 构造函数
   *
   * @param value T 类型的值
   */
  function Optional(value) {
    (0, _classCallCheck2["default"])(this, Optional);
    this.value = value;
  }
  /**
   * 返回一个指定 T 类型的值的 Optional 实例
   *
   * @param value T 类型的值
   * @return T 类型的值的 Optional 实例
   */
  return (0, _createClass2["default"])(Optional, [{
    key: "get",
    value:
    /**
     * 如果 value 不为 null 或 undefined，则返回 value 的值；否则抛出异常
     *
     * @return Optional 中包含这个值
     */
    function get() {
      if (this.value === null || typeof this.value === "undefined") {
        throw "No value present";
      }
      return this.value;
    }
    /**
     * 如果 value 不为 null 或 undefined，则返回 value 的值；否则返回 other
     *
     * @param other 其它值
     * @return value 不为 null 或 undefined，则返回 value 的值；否则返回 other
     */
  }, {
    key: "orElse",
    value: function orElse(other) {
      return Object.isUndefinedOrNull(this.value) ? other : this.value;
    }
    /**
     * 如果 value 不为 null 或 undefined，则返回 true；否则返回 false
     *
     * @return value 不为 null 或 undefined，则返回 true；否则返回 false
     */
  }, {
    key: "isPresent",
    value: function isPresent() {
      return Object.isUndefinedOrNull(this.value) === false;
    }
  }], [{
    key: "of",
    value: function of(value) {
      return new Optional(value);
    }
    /**
     * 如果为非 null 或 undefined，返回 Optional 描述的指定值的实例，否则返回空的 Optional 实例
     *
     * @param value T 类型的值
     * @return T 类型的值的 Optional 实例，或空的 Optional 实例
     */
  }, {
    key: "ofNullable",
    value: function ofNullable(value) {
      return Object.isUndefinedOrNull(value) ? Optional.empty() : new Optional(value);
    }
    /**
     * 返回空的 Optional 实例
     *
     * @return 空的 Optional 实例
     */
  }, {
    key: "empty",
    value: function empty() {
      return new Optional(null);
    }
  }]);
}();
window.Optional = Optional;